@@ -13,14 +13,14 @@ subparsers = parser.add_subparsers(description='Please invoke BSBolt module for
                                    metavar='Index, Align, CallMethylation, AggregateMatrix, Simulate, Impute',
                                    dest='subparser_name')
 
-align_parser = subparsers.add_parser('Align', help='Alignment Module', usage=alignment_help, add_help=False)
-index_parser = subparsers.add_parser('Index', help='Index Generation Module', usage=index_help, add_help=False)
-call_meth_parser = subparsers.add_parser('CallMethylation', help='Methylation Calling Module',
+align_parser = subparsers.add_parser('Align', help='Alignment', usage=alignment_help, add_help=False)
+index_parser = subparsers.add_parser('Index', help='Index Generation', usage=index_help, add_help=False)
+call_meth_parser = subparsers.add_parser('CallMethylation', help='Methylation Calling',
                                          usage=meth_help, add_help=False)
-matrix_parser = subparsers.add_parser('AggregateMatrix', help='CGmap Matrix Aggregation Module', add_help=False,
+matrix_parser = subparsers.add_parser('AggregateMatrix', help='CGmap Matrix Aggregation', add_help=False,
                                       usage=aggregate_help)
-sim_parser = subparsers.add_parser('Simulate', help='Read Simulation Module', add_help=False, usage=sim_help)
-imputation_parser = subparsers.add_parser('Impute', help='kNN Imputation Module', add_help=False, usage=impute_help)
+sim_parser = subparsers.add_parser('Simulate', help='Read Simulation', add_help=False, usage=sim_help)
+imputation_parser = subparsers.add_parser('Impute', help='kNN Imputation', add_help=False, usage=impute_help)
 sort_parser = subparsers.add_parser('Sort', help='BAM Sort')
 bam_index = subparsers.add_parser('BamIndex', help='BAM Index')
 # Add Alignment Parser Commands
@@ -36,6 +36,8 @@ align_parser.add_argument('-CP', type=float, default=0.5, help='CH conversion pr
                           required=False)
 align_parser.add_argument('-CT', type=int, default=5, help='number of CH sites needed to assess read conversion',
                           required=False)
+align_parser.add_argument('-SP', type=float, default=0.1, help='substitution threshold for read bisulfite '
+                                                               'conversion patterns (ie C2T, G2A) [0.1]')
 align_parser.add_argument('-t', type=int, default=1, help='number of bwa threads [1]', required=False)
 align_parser.add_argument('-k', type=int, default=19, help='minimum seed length [19]', required=False)
 align_parser.add_argument('-w', type=int, default=100, help='band width for banded alignment [100]', required=False)
@@ -94,7 +96,9 @@ align_parser.add_argument('-XA', type=lambda x: x.strip(), default='100,200',
                           help='if there are <INT hits with score >80 percent of the max score, '
                                'output all in XA [100,200]',
                           required=False)
-align_parser.add_argument('-DR', type=float, default=0.95, help='drop ratio for alternative hits reported in XA tag, for best bisulifte alignment performance set at or above default [0.95]')
+align_parser.add_argument('-DR', type=float, default=0.95, help='drop ratio for alternative hits reported in XA tag, '
+                                                                'for best bisulifte alignment performance set at or '
+                                                                'above default [0.95]')
 align_parser.add_argument('-M', action='store_true', default=False,
                           help='mark shorter split hits as secondary',
                           required=False)
